@@ -7,7 +7,6 @@ from .properties.vapor_pressure import vapor_pressure_handle
 from .properties.phase_change import (normal_boiling_point_temperature,
                                       normal_melting_point_temperature,
                                       heat_of_fusion,
-                                      heat_of_sublimation,
                                       heat_of_vaporization_handle)
 from .properties.critical import (Ihmels,
                                   critical_point_temperature,
@@ -22,26 +21,31 @@ from .properties.volume import volume_handle
 from .properties.heat_capacity import heat_capacity_handle
 from .properties.reaction import heat_of_formation
 from .properties.combustion import CombustionData
-from .properties.elements import compute_similarity_variable, parse_simple_formula
+from .properties.elements import (compute_similarity_variable, 
+                                  parse_simple_formula,
+                                  compute_molecular_weight)
 from .properties.eos import GCEOS_DUMMY, PR
 from .properties.viscosity import viscosity_handle
 from .properties.thermal_conductivity import thermal_conductivity_handle
-from .properties.free_energy import \
-    EnthalpyRefSolid, EnthalpyRefLiquid, EnthalpyRefGas, \
-    EntropyRefSolid, EntropyRefLiquid, EntropyRefGas, \
-    ExcessEnthalpyRefSolid, ExcessEnthalpyRefLiquid, ExcessEnthalpyRefGas, \
-    ExcessEntropyRefSolid, ExcessEntropyRefLiquid, ExcessEntropyRefGas
-from .base import PhaseHandle, PhaseTHandle, PhaseTPHandle, \
-                  ThermoModelHandle, TDependentModelHandle, TPDependentModelHandle, \
-                  display_asfunctor
+from .properties.free_energy import (
+    EnthalpyRefSolid, EnthalpyRefLiquid, EnthalpyRefGas,
+    EntropyRefSolid, EntropyRefLiquid, EntropyRefGas,
+    ExcessEnthalpyRefSolid, ExcessEnthalpyRefLiquid, ExcessEnthalpyRefGas,
+    ExcessEntropyRefSolid, ExcessEntropyRefLiquid, ExcessEntropyRefGas)
+from .base import (PhaseHandle, PhaseTHandle, PhaseTPHandle,
+                   ThermoModelHandle, TDependentModelHandle,
+                   TPDependentModelHandle, display_asfunctor)
 from .base.units_of_measure import chemical_units_of_measure
 from .properties.dipole import dipole_moment
 from . import functional as fn 
 from .properties.permittivity import permitivity_handle
 from .properties.interface import surface_tension_handle
-from .equilibrium.unifac_data import \
-    DDBST_UNIFAC_assignments, DDBST_MODIFIED_UNIFAC_assignments, DDBST_PSRK_assignments, \
-    UNIFACGroupCounts, DortmundGroupCounts, PSRKGroupCounts
+from .equilibrium.unifac_data import (DDBST_UNIFAC_assignments, 
+                                      DDBST_MODIFIED_UNIFAC_assignments,
+                                      DDBST_PSRK_assignments,
+                                      UNIFACGroupCounts, 
+                                      DortmundGroupCounts, 
+                                      PSRKGroupCounts)
 from .exceptions import DomainError
 # from .solubility import SolubilityParameter
 # from .lennard_jones import Stockmayer, MolecularDiameter
@@ -90,27 +94,36 @@ def create_eos(eos, Tc, Pc, omega):
 
 def reset_constant(chemical, var, value):
     getfield = getattr
-    for handle in _handles: 
+    setattr(chemical, '_'+var, value)
+    for handle in _model_and_phase_handles: 
+        getfield(chemical, handle).set_value(var, value)
+
+def reset_energy_constant(chemical, var, value):
+    getfield = getattr
+    for handle in _energy_handles: 
         getfield(chemical, handle).set_value(var, value)
 
 def raise_helpful_handle_error(handle):
     var = handle.var
     if isinstance(handle, PhaseHandle):
-        raise TypeError(f"cannot set '{var}'; use the `add_model` "
-                        f"and the `set_model_priority` methods of each phase "
-                        f"handle to modify the thermodynamic properties for "
-                        f"each phase (e.g. {var}.l.add_model(...))")
+        raise AttributeError(
+            f"cannot set '{var}'; use the `add_model` "
+            f"and the `set_model_priority` methods "
+            f"to modify the thermodynamic properties for "
+            f"each phase (e.g. {var}.l.add_model(...))")
     elif isinstance(handle, ThermoModelHandle):
-        raise TypeError(f"cannot set '{var}'; use the `{var}.add_model` "
-                        f"and the `{var}.set_model_priority` methods to "
-                        f"modify the thermodynamic property instead")
+        raise AttributeError(
+            f"cannot set '{var}'; use the `{var}.add_model` "
+            f"and the `{var}.set_model_priority` methods to "
+            f"modify the thermodynamic property instead")
     else:
-        raise Exception('expected a PhaseHandle or a ThermoModelHandle object; '
-                       f'got a {type(handle).__name__} instead')
+        raise Exception(
+            'expected a PhaseHandle or a ThermoModelHandle object; '
+           f'got a {type(handle).__name__} instead')
 
 def raise_helpful_energy_functor_error(energy_functor):
     var = energy_functor.var
-    raise TypeError(f"cannot set '{var}'; use the `reset_free_energies` "
+    raise AttributeError(f"cannot set '{var}'; use the `<Chemical>.reset_free_energies` "
                      "method to reset the free energy models with updated "
                      "chemical data")
 
@@ -143,11 +156,11 @@ _model_and_phase_properties = ('Psat', 'Hvap', 'sigma', 'epsilon',
 _handles = _model_and_phase_handles + _energy_handles
 
 _data = ('_MW', '_Tm', '_Tb', '_Tt', '_Tc', '_Pt', '_Pc', '_Vc',
-         '_Hf', '_LHV', '_HHV', '_Hfus', '_Hsub', '_omega', '_dipole',
+         '_Hf', '_LHV', '_HHV', '_Hfus', '_omega', '_dipole',
          '_similarity_variable', '_iscyclic_aliphatic', '_combustion')
 
 _functor_data = {'MW', 'Tm', 'Tb', 'Tt', 'Pt', 'Tc', 'Pc', 'Vc',
-                 'Hfus', 'Hsub', 'omega', 'dipole',
+                 'Hfus', 'omega', 'dipole',
                  'similarity_variable', 'iscyclic_aliphatic'}
 
 _checked_properties = ('phase_ref', 'eos', 'eos_1atm',
@@ -213,7 +226,6 @@ class Chemical:
              LHV: None
              HHV: None
              Hfus: 6010 J/mol
-             Hsub: None
              omega: 0.344
              dipole: None
              similarity_variable: 0.16653
@@ -541,7 +553,6 @@ class Chemical:
                  LHV: None
                  HHV: None
                  Hfus: None
-                 Hsub: None
                  omega: None
                  dipole: None
                  similarity_variable: None
@@ -582,7 +593,7 @@ class Chemical:
         for i,j in data.items(): setfield(self, '_' + i , j)
         self._eos = create_eos(PR, self._Tc, self._Pc, self._omega)
         self._eos_1atm = self._eos.to_TP(298.15, 101325)
-        
+        if self._formula: self.reset_combustion_data()
         return self
 
     def copy(self, ID, CAS=None):
@@ -617,6 +628,7 @@ class Chemical:
         if phase not in ('s', 'l', 'g'):
             raise ValueError("phase must be either 's', 'l', or 'g'")
         self._phase_ref = phase
+        self.reset_free_energies()
 
     ### Unchangeable properties ###
 
@@ -686,6 +698,10 @@ class Chemical:
     @formula.setter
     def formula(self, formula):
         self._formula = str(formula)
+        if self._Hf is None:
+            self._MW = compute_molecular_weight(self.atoms)
+        else:
+            self.reset_combustion_data()
     
     ### Functional groups ###
     
@@ -831,6 +847,7 @@ class Chemical:
     @Tm.setter
     def Tm(self, Tm):
         reset_constant(self, 'Tm', float(Tm))
+        self.reset_free_energies()
     
     @property
     def Tb(self):
@@ -839,6 +856,15 @@ class Chemical:
     @Tb.setter
     def Tb(self, Tb):
         reset_constant(self, 'Tb', float(Tb))
+        self.reset_free_energies()
+    
+    @property
+    def Pt(self):
+        """Triple point pressure [Pa]."""
+        return self._Pt
+    @Pt.setter
+    def Pt(self, Pt):
+        self._Pt = float(Pt)
     
     @property
     def Tt(self):
@@ -846,7 +872,7 @@ class Chemical:
         return self._Tt
     @Tt.setter
     def Tt(self, Tt):
-        reset_constant(self, 'Tt', float(Tt))
+        self._Tt = float(Tt)
     
     @property
     def Tc(self):
@@ -856,14 +882,6 @@ class Chemical:
     def Tc(self, Tc):
         reset_constant(self, 'Tc',float(Tc))
     
-    @property
-    def Pt(self):
-        """Triple point pressure [Pa]."""
-        return self._Pt
-    @Pt.setter
-    def Pt(self, Pt):
-        reset_constant(self, 'Pt', float(Pt))
-    
     @property
     def Pc(self):
         """Critical point pressure [Pa]."""
@@ -886,15 +904,7 @@ class Chemical:
         return self._Hfus
     @Hfus.setter
     def Hfus(self, Hfus):
-        reset_constant(self, 'Hfus', float(Hfus))
-    
-    @property
-    def Hsub(self):
-        """Heat of sublimation [J/mol]."""
-        return self._Hsub
-    @Hsub.setter
-    def Hsub(self, Hsub):
-        reset_constant(self, 'Hsub', float(Hsub))
+        reset_energy_constant(self, 'Hfus', float(Hfus))
     
     @property
     def omega(self):
@@ -999,7 +1009,7 @@ class Chemical:
 
     @property
     def atoms(self):
-        """dict[str: int] Atom-count pairs based on formula"""
+        """dict[str: int] Atom-count pairs based on formula."""
         formula = self._formula
         return parse_simple_formula(formula) if formula else None
     
@@ -1057,7 +1067,7 @@ class Chemical:
               formula=None, MW=None, Tm=None,
               Tb=None, Tc=None, Pc=None, Vc=None, omega=None,
               Tt=None, Pt=None, Hf=None, LHV=None, combustion=None,
-              HHV=None, Hfus=None, Hsub=None, dipole=None,
+              HHV=None, Hfus=None, dipole=None,
               similarity_variable=None, iscyclic_aliphatic=None):
         """
         Reset all chemical properties.
@@ -1085,6 +1095,8 @@ class Chemical:
             common_name = common_name or info.common_name
             formula = formula or info.formula
             MW = MW or info.MW
+        if formula and not MW:
+            MW = compute_molecular_weight(formula)
         self._locked_state = None
         self._init_names(CAS, smiles, InChI, InChI_key, 
                          pubchemid, iupac_name, common_name,
@@ -1093,43 +1105,26 @@ class Chemical:
         if CAS == '56-81-5': # TODO: Make this part of data
             self._Dortmund = DortmundGroupCounts({2: 2, 3: 1, 14: 2, 81: 1})
         self._init_data(CAS, MW, Tm, Tb, Tc, Pc,
-                        Vc, omega, Pt, Tt, Hfus, Hsub, Hf, LHV,
+                        Vc, omega, Pt, Tt, Hfus, Hf, LHV,
                         HHV, combustion, dipole, similarity_variable,
                         iscyclic_aliphatic)
         self._init_eos(eos, self._Tc, self._Pc, self._omega)
         self._init_handles(CAS, self._MW, self._Tm, self._Tb, self._Tc,
-                           self._Pc, self.Zc, self._Vc, self._Hfus,
+                           self._Pc, self.Zc, self._Vc,
                            self._omega, self._dipole, self._similarity_variable,
                            self._iscyclic_aliphatic, self._eos, self.has_hydroxyl)
         self._estimate_missing_properties()
         self._init_energies(self._Cn, self._Hvap, self._Psat, self._Hfus,
                             self._Tm, self._Tb, self._eos, self._eos_1atm,
                             phase_ref)
-    
-    def reset_constants(self, **data):
-        """Reset constant data (e.g. Tb, Tm, Hfus, etc.)"""
-        setfield = setattr
-        getfield = getattr
-        if 'Hf' in data:
-            self._Hf = data.pop('Hf')
-        if 'LHV' in data:
-            self._LHV = data.pop('LHV')
-        if 'HHV' in data:
-            self._HHV = data.pop('HHV')
-        if 'combustion' in data:
-            self._combustion = data.pop('combustion')
-        for i in data:
-            if i in _functor_data: 
-                setfield(self, '_' + i, data[i])
-            else:
-                raise ValueError(f"invalid data key {i}")
-        for handle in _handles: getfield(self, handle).load_data_from(data)
+        if self._Hf: self.reset_combustion_data()
 
     def reset_combustion_data(self, method="Stoichiometry"):
         """Reset combustion data (LHV, HHV, and combution attributes)
         based on the molecular formula and the heat of formation."""
         CD = CombustionData.from_chemical_data(self.atoms, self._CAS,
                                                self._MW, self._Hf, method)
+        if not self._MW: self._MW = CD.MW
         self._LHV = CD.LHV
         self._HHV = CD.HHV
         self._combustion = CD.stoichiometry
@@ -1173,7 +1168,7 @@ class Chemical:
             self._PSRK = PSRKGroupCounts()
 
     def _init_data(self, CAS, MW, Tm, Tb, Tc, Pc,
-                   Vc, omega, Pt, Tt, Hfus, Hsub, Hf, LHV,
+                   Vc, omega, Pt, Tt, Hfus, Hf, LHV,
                    HHV, combustion, dipole, similarity_variable,
                    iscyclic_aliphatic):
         self._MW = MW
@@ -1192,14 +1187,13 @@ class Chemical:
 
         # Energy
         self._Hfus = Hfus or heat_of_fusion(CAS)
-        self._Hsub = Hsub or heat_of_sublimation(CAS)
 
         # Chemistry
         self._Hf = Hf or heat_of_formation(CAS)
         atoms = self.atoms
         if not all([LHV, HHV, combustion]) and atoms and Hf:
             CD = CombustionData.from_chemical_data(
-                atoms, self._CAS, MW, self._Hf)
+                 atoms, self._CAS, MW, self._Hf)
             LHV = CD.LHV
             HHV = CD.HHV
             combustion = CD.stoichiometry
@@ -1218,7 +1212,7 @@ class Chemical:
         self._eos = create_eos(eos, Tc, Pc, omega)
         self._eos_1atm = self._eos.to_TP(298.15, 101325)
 
-    def _init_handles(self, CAS, MW, Tm, Tb, Tc, Pc, Zc, Vc, Hfus, omega,
+    def _init_handles(self, CAS, MW, Tm, Tb, Tc, Pc, Zc, Vc, omega,
                       dipole, similarity_variable, iscyclic_aliphatic, eos,
                       has_hydroxyl):
         # Vapor pressure
@@ -1248,7 +1242,7 @@ class Chemical:
         self._mu = mu = viscosity_handle(None, ldata, gdata)
         
         # Conductivity
-        ldata = (CAS, MW, Tm, Tb, Tc, Pc, omega, Hfus)
+        ldata = (CAS, MW, Tm, Tb, Tc, Pc, omega)
         gdata = (CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, dipole, V.g, Cn.g, mu.g)
         self._kappa = kappa = thermal_conductivity_handle(None, ldata, gdata)
         
@@ -1501,7 +1495,7 @@ class Chemical:
         >>> Substance = Chemical.blank('Substance')
         >>> missing_properties = Substance.default()
         >>> sorted(missing_properties)
-        ['Dortmund', 'Hfus', 'Hsub', 'Hvap', 'PSRK', 'Pc', 'Psat', 'Pt', 'Tb', 'Tc', 'Tm', 'Tt', 'UNIFAC', 'V', 'Vc', 'dipole', 'iscyclic_aliphatic', 'omega', 'similarity_variable']
+        ['Dortmund', 'Hfus', 'Hvap', 'PSRK', 'Pc', 'Psat', 'Pt', 'Tb', 'Tc', 'Tm', 'Tt', 'UNIFAC', 'V', 'Vc', 'dipole', 'iscyclic_aliphatic', 'omega', 'similarity_variable']
         
         Note that missing properties does not include essential properties volume, heat capacity, and conductivity.
         
@@ -1598,7 +1592,7 @@ class Chemical:
         >>> from thermosteam import Chemical
         >>> Substance = Chemical.blank('Substance', phase_ref='l')
         >>> sorted(Substance.get_missing_properties())
-        ['Cn', 'Dortmund', 'H', 'HHV', 'H_excess', 'Hf', 'Hfus', 'Hsub', 'Hvap', 'LHV', 'MW', 'PSRK', 'Pc', 'Psat', 'Pt', 'S', 'S_excess', 'Tb', 'Tc', 'Tm', 'Tt', 'UNIFAC', 'V', 'Vc', 'combustion', 'dipole', 'epsilon', 'iscyclic_aliphatic', 'kappa', 'mu', 'omega', 'sigma', 'similarity_variable']
+        ['Cn', 'Dortmund', 'H', 'HHV', 'H_excess', 'Hf', 'Hfus', 'Hvap', 'LHV', 'MW', 'PSRK', 'Pc', 'Psat', 'Pt', 'S', 'S_excess', 'Tb', 'Tc', 'Tm', 'Tt', 'UNIFAC', 'V', 'Vc', 'combustion', 'dipole', 'epsilon', 'iscyclic_aliphatic', 'kappa', 'mu', 'omega', 'sigma', 'similarity_variable']
         
         """
         getfield = getattr
