@@ -8,8 +8,8 @@ from ._stream import Stream
 from ._thermal_condition import ThermalCondition
 from .indexer import MolarFlowIndexer
 from ._settings import settings
-from .equilibrium import VLE, LLE
-from .utils import Cache
+from . import equilibrium as eq
+from . import utils
 import numpy as np
 
 __all__ = ('MultiStream', )
@@ -198,10 +198,14 @@ class MultiStream(Stream):
     def _init_cache(self):
         super()._init_cache()
         self._streams = {}
-        self._vle_cache = Cache(VLE, self._imol, self._thermal_condition, thermo=self._thermo,
-                                bubble_point_cache=self._bubble_point_cache,
-                                dew_point_cache=self._dew_point_cache)
-        self._lle_cache = Cache(LLE, self._imol, self._thermal_condition, self._thermo)
+        self._vle_cache = eq.VLECache(self._imol,
+                                      self._thermal_condition, 
+                                      self._thermo,
+                                      self._bubble_point_cache,
+                                      self._dew_point_cache)
+        self._lle_cache = eq.LLECache(self._imol,
+                                      self._thermal_condition, 
+                                      self._thermo)
         
     def __getitem__(self, phase):
         streams = self._streams
@@ -557,11 +561,10 @@ class MultiStream(Stream):
         return basic_info + phases_flow_rates_info.rstrip('\n')
     
     def print(self):
-        from .utils import repr_kwarg, repr_couples
         IDs = self.chemicals.IDs
         phase_data = []
         for phase, data in self.imol:
-            IDdata = repr_couples(", ", IDs, data)
+            IDdata = utils.repr_couples(", ", IDs, data)
             if IDdata:
                 phase_data.append(f"{phase}=[{IDdata}]")
         dlim = ", "
@@ -569,7 +572,7 @@ class MultiStream(Stream):
         phases = f'phases={self.phases}'
         if phase_data:
             phase_data = dlim + phase_data
-        price = repr_kwarg('price', self.price)
+        price = utils.repr_kwarg('price', self.price)
         print(f"{type(self).__name__}(ID={repr(self.ID)}, {phases}, T={self.T:.2f}, "
               f"P={self.P:.6g}{price}{phase_data})")
     
\ No newline at end of file
