@@ -5,17 +5,16 @@ Created on Tue Nov 26 02:34:56 2019
 @author: yoelr
 """
 import numpy as np
+import thermosteam as tmo
 from . import indexer
 from . import equilibrium as eq
 from . import functional as fn
 from .base import units_of_measure as thermo_units
 from .exceptions import DimensionError
-from ._thermal_condition import ThermalCondition
 from . import utils
 
 __all__ = ('Stream', )
 
-
 # %% Utilities
 
 mol_units = indexer.ChemicalMolarFlowIndexer.units
@@ -23,6 +22,7 @@ mass_units = indexer.ChemicalMassFlowIndexer.units
 vol_units = indexer.ChemicalVolumetricFlowIndexer.units
 
 # %%
+
 @utils.thermo_user
 @utils.registered(ticket_name='s')
 class Stream:
@@ -38,7 +38,7 @@ class Stream:
     ID='' : str
         A unique identification. If ID is None, stream will not be registered.
         If no ID is given, stream will be registered with a unique ID.
-    flow=() : tuple
+    flow=() : Iterable[float]
         All flow rates corresponding to chemical `IDs`.
     phase='l' : 'l', 'g', or 's'
         Either gas (g), liquid (l), or solid (s).
@@ -214,9 +214,9 @@ class Stream:
 
     _flow_cache = {}
 
-    def __init__(self, ID='', flow=(), phase='l', T=298.15, P=101325., units='kmol/hr',
-                 price=0., thermo=None, **chemical_flows):
-        self._thermal_condition = ThermalCondition(T, P)
+    def __init__(self, ID= '', flow=(), phase='l', T=298.15, P=101325.,
+                 units='kmol/hr', price=0., thermo=None, **chemical_flows):
+        self._thermal_condition = tmo.ThermalCondition(T, P)
         thermo = self._load_thermo(thermo)
         self._init_indexer(flow, phase, thermo.chemicals, chemical_flows)
         self.price = price 
@@ -267,8 +267,8 @@ class Stream:
         self._imol = imol
 
     def _init_cache(self):
-        self._bubble_point_cache = utils.Cache(eq.BubblePoint)
-        self._dew_point_cache = utils.Cache(eq.DewPoint)
+        self._bubble_point_cache = eq.BubblePointCache()
+        self._dew_point_cache = eq.DewPointCache()
 
     @classmethod
     def _get_flow_name_and_factor(cls, units):
@@ -294,7 +294,7 @@ class Stream:
 
     ### Property getters ###
 
-    def get_flow(self, units, key=...):
+    def get_flow(self, units, key= ...):
         """
         Return an flow rates in requested units.
         
@@ -302,7 +302,7 @@ class Stream:
         ----------
         units : str
             Units of measure.
-        key : Iterable[str] or str, optional
+        key : tuple[str] or str, optional
             Chemical identifiers.
 
         Examples
@@ -318,7 +318,7 @@ class Stream:
         indexer = getattr(self, 'i' + name)
         return factor * indexer[key]
     
-    def set_flow(self, data, units, key=...):
+    def set_flow(self, data, units, key= ...):
         """
         Set flow rates in given units.
 
@@ -584,7 +584,7 @@ class Stream:
         """[float] Enthalpy flow rate in kJ/hr."""
         return self.mixture.H(self.phase, self.mol, *self._thermal_condition)
     @H.setter
-    def H(self, H):
+    def H(self, H:float):
         self.T = self.mixture.solve_T(self.phase, self.mol, H, *self._thermal_condition)
 
     @property
@@ -886,7 +886,7 @@ class Stream:
         ----------
         stream : Stream
             Flow rates will be copied from here.
-        IDs=... : iterable[str], defaults to all chemicals.
+        IDs=... : Iterable[str], defaults to all chemicals.
             Chemical IDs. 
         remove=False: bool, optional
             If True, copied chemicals will be removed from `stream`.
@@ -949,7 +949,7 @@ class Stream:
         
         self.mol[index] = mol[index]
         if remove: 
-            if isinstance(stream, ms.MultiStream):
+            if isinstance(stream, tmo.MultiStream):
                 mol[..., index] = 0
             else:
                 mol[index] = 0
@@ -1035,8 +1035,6 @@ class Stream:
         new._thermo = self._thermo
         new._imol = self._imol
         new._thermal_condition = self._thermal_condition
-        new._bubble_point_cache = self._bubble_point_cache
-        new._dew_point_cache = self._dew_point_cache
         try: new._vle_cache = self._vle_cache
         except AttributeError: pass
         return new
@@ -1105,7 +1103,7 @@ class Stream:
         
         """
         chemicals = self.chemicals[IDs] if IDs else self.vle_chemicals
-        bp = self._bubble_point_cache.reload(chemicals, self._thermo)
+        bp = self._bubble_point_cache(chemicals, self._thermo)
         return bp
     
     def get_dew_point(self, IDs=None):
@@ -1127,7 +1125,7 @@ class Stream:
         
         """
         chemicals = self.chemicals.retrieve(IDs) if IDs else self.vle_chemicals
-        dp = self._dew_point_cache.reload(chemicals, self._thermo)
+        dp = self._dew_point_cache(chemicals, self._thermo)
         return dp
     
     def bubble_point_at_T(self, T=None, IDs=None):
@@ -1380,11 +1378,6 @@ class Stream:
         """
         Receive vapors from another stream as if in equilibrium.
 
-        Parameters
-        ----------
-        IDs : tuple[str]
-            IDs of chemicals.
-
         Examples
         --------
         >>> import thermosteam as tmo
@@ -1432,16 +1425,17 @@ class Stream:
         return (self.phase,)
     @phases.setter
     def phases(self, phases):
-        self.__class__ = ms.MultiStream
+        self.__class__ = tmo.MultiStream
         self._imol = self._imol.to_material_indexer(phases)
         self._streams = {}
-        self._vle_cache = utils.Cache(
-                              eq.VLE, self._imol, self._thermal_condition,
-                              thermo=self._thermo,
-                              bubble_point_cache=self._bubble_point_cache,
-                              dew_point_cache=self._dew_point_cache)
-        self._lle_cache = utils.Cache(eq.LLE, self._imol,
-                                      self._thermal_condition, self._thermo)
+        self._vle_cache = eq.VLECache(self._imol,
+                                      self._thermal_condition,
+                                      self._thermo, 
+                                      self._bubble_point_cache,
+                                      self._dew_point_cache)
+        self._lle_cache = eq.LLECache(self._imol,
+                                      self._thermal_condition,
+                                      self._thermo)
     
     ### Representation ###
     
@@ -1539,5 +1533,3 @@ class Stream:
         price = utils.repr_kwarg('price', self.price)
         print(f"{type(self).__name__}(ID={repr(self.ID)}, phase={repr(self.phase)}, T={self.T:.2f}, "
               f"P={self.P:.6g}{price}{chemical_flows})")
-    
-from . import _multi_stream as ms
\ No newline at end of file
