@@ -4,8 +4,7 @@ Created on Thu Mar 26 12:14:29 2020
 
 @author: yoelr
 """
-from ..utils import njitable
-from flexsolve import IQ_interpolation
+from flexsolve import IQ_interpolation, njitable
 
 __all__ = ('phase_fraction', 'solve_phase_fraction',
            'compute_phase_fraction_2N', 'compute_phase_fraction_3N')
