@@ -11,6 +11,7 @@ from .bubble_point import BubblePoint
 from .lle import LLE
 from ..indexer import MaterialIndexer
 from math import floor
+from flexsolve import speed_up
 import thermosteam as tmo
 import numpy as np
 import ternary
@@ -144,7 +145,7 @@ def plot_lle_ternary_diagram(carrier, solvent, solute, T, P=101325, thermo=None,
     .. figure:: ../images/water_ethanol_ethyl_acetate_ternary_diagram.png
 
     """
-    tmo.speed_up()
+    speed_up()
     chemicals = [carrier, solvent, solute]
     thermo = as_thermo(thermo, chemicals)
     chemicals = thermo.chemicals
