@@ -4,7 +4,7 @@ Free energy functors for Chemical objects.
 
 """
 from .._constants import R
-from ..base import H, S, PhaseTPropertyBuilder, PhaseTPPropertyBuilder
+from ..base import H, S, PhaseTFunctorBuilder, PhaseTPFunctorBuilder
 from math import log
     
 @H.l
@@ -48,20 +48,20 @@ def Gas_Enthalpy_Ref_Solid(T, Cn_g, H_int_T_ref_to_Tm_s, Hfus,
     return H_ref + H_int_T_ref_to_Tm_s + Hfus + H_int_Tm_to_Tb_l + Hvap_Tb + Cn_g.integrate_by_T(Tb, T)
 
 
-EnthalpyRefLiquid = PhaseTPropertyBuilder('H',
-                                          Solid_Enthalpy_Ref_Liquid,
-                                          Liquid_Enthalpy_Ref_Liquid,
-                                          Gas_Enthalpy_Ref_Liquid)
+EnthalpyRefLiquid = PhaseTFunctorBuilder('H',
+                                        Solid_Enthalpy_Ref_Liquid,
+                                        Liquid_Enthalpy_Ref_Liquid,
+                                        Gas_Enthalpy_Ref_Liquid)
 
-EnthalpyRefSolid = PhaseTPropertyBuilder('H',
-                                         Solid_Enthalpy_Ref_Solid,
-                                         Liquid_Enthalpy_Ref_Solid,
-                                         Gas_Enthalpy_Ref_Solid)
+EnthalpyRefSolid = PhaseTFunctorBuilder('H',
+                                       Solid_Enthalpy_Ref_Solid,
+                                       Liquid_Enthalpy_Ref_Solid,
+                                       Gas_Enthalpy_Ref_Solid)
 
-EnthalpyRefGas = PhaseTPropertyBuilder('H',
-                                       Solid_Enthalpy_Ref_Gas,
-                                       Liquid_Enthalpy_Ref_Gas,
-                                       Gas_Enthalpy_Ref_Gas)
+EnthalpyRefGas = PhaseTFunctorBuilder('H',
+                                     Solid_Enthalpy_Ref_Gas,
+                                     Liquid_Enthalpy_Ref_Gas,
+                                     Gas_Enthalpy_Ref_Gas)
 
 @S.l
 def Liquid_Entropy_Ref_Liquid(T, Cn_l, T_ref, S_ref):
@@ -104,20 +104,20 @@ def Gas_Entropy_Ref_Solid(T, P, Cn_g, S_int_T_ref_to_Tm_s, Sfus,
     return S_ref + S_int_T_ref_to_Tm_s + Sfus + S_int_Tm_to_Tb_l + Svap_Tb + Cn_g.integrate_by_T_over_T(Tb, T) - R*log(P/P_ref)
 
 
-EntropyRefLiquid = PhaseTPPropertyBuilder('S',
-                                          Solid_Entropy_Ref_Liquid,
-                                          Liquid_Entropy_Ref_Liquid,
-                                          Gas_Entropy_Ref_Liquid)
+EntropyRefLiquid = PhaseTPFunctorBuilder('S',
+                                        Solid_Entropy_Ref_Liquid,
+                                        Liquid_Entropy_Ref_Liquid,
+                                        Gas_Entropy_Ref_Liquid)
 
-EntropyRefSolid = PhaseTPPropertyBuilder('S',
-                                         Solid_Entropy_Ref_Solid,
-                                         Liquid_Entropy_Ref_Solid,
-                                         Gas_Entropy_Ref_Solid)
+EntropyRefSolid = PhaseTPFunctorBuilder('S',
+                                       Solid_Entropy_Ref_Solid,
+                                       Liquid_Entropy_Ref_Solid,
+                                       Gas_Entropy_Ref_Solid)
 
-EntropyRefGas = PhaseTPPropertyBuilder('S',
-                                       Solid_Entropy_Ref_Gas,
-                                       Liquid_Entropy_Ref_Gas,
-                                       Gas_Entropy_Ref_Gas)
+EntropyRefGas = PhaseTPFunctorBuilder('S',
+                                     Solid_Entropy_Ref_Gas,
+                                     Liquid_Entropy_Ref_Gas,
+                                     Gas_Entropy_Ref_Gas)
 
 @H.l
 def Excess_Liquid_Enthalpy_Ref_Liquid(T, P):
@@ -158,20 +158,20 @@ def Excess_Gas_Enthalpy_Ref_Liquid(T, P, eos, H_dep_T_ref_Pb,
 def Excess_Gas_Enthalpy_Ref_Solid(T):
     return 0
 
-ExcessEnthalpyRefLiquid = PhaseTPPropertyBuilder('H_excess',
-                                                 Excess_Solid_Enthalpy_Ref_Liquid,
-                                                 Excess_Liquid_Enthalpy_Ref_Liquid,
-                                                 Excess_Gas_Enthalpy_Ref_Liquid)
+ExcessEnthalpyRefLiquid = PhaseTPFunctorBuilder('H_excess',
+                                               Excess_Solid_Enthalpy_Ref_Liquid,
+                                               Excess_Liquid_Enthalpy_Ref_Liquid,
+                                               Excess_Gas_Enthalpy_Ref_Liquid)
 
-ExcessEnthalpyRefSolid = PhaseTPPropertyBuilder('H_excess',
+ExcessEnthalpyRefSolid = PhaseTPFunctorBuilder('H_excess',
                                                 Excess_Solid_Enthalpy_Ref_Solid,
                                                 Excess_Liquid_Enthalpy_Ref_Solid,
                                                 Excess_Gas_Enthalpy_Ref_Solid)
 
-ExcessEnthalpyRefGas = PhaseTPPropertyBuilder('H_excess',
-                                              Excess_Solid_Enthalpy_Ref_Gas,
-                                              Excess_Liquid_Enthalpy_Ref_Gas,
-                                              Excess_Gas_Enthalpy_Ref_Gas)
+ExcessEnthalpyRefGas = PhaseTPFunctorBuilder('H_excess',
+                                            Excess_Solid_Enthalpy_Ref_Gas,
+                                            Excess_Liquid_Enthalpy_Ref_Gas,
+                                            Excess_Gas_Enthalpy_Ref_Gas)
 
 @S.l
 def Excess_Liquid_Entropy_Ref_Liquid(T, P):
@@ -212,17 +212,17 @@ def Excess_Gas_Entropy_Ref_Liquid(T, P, eos, S_dep_T_ref_Pb,
 def Excess_Gas_Entropy_Ref_Solid(T):
     return 0
 
-ExcessEntropyRefLiquid = PhaseTPPropertyBuilder('S_excess',
-                                                Excess_Solid_Entropy_Ref_Liquid,
-                                                Excess_Liquid_Entropy_Ref_Liquid,
-                                                Excess_Gas_Entropy_Ref_Liquid)
+ExcessEntropyRefLiquid = PhaseTPFunctorBuilder('S_excess',
+                                              Excess_Solid_Entropy_Ref_Liquid,
+                                              Excess_Liquid_Entropy_Ref_Liquid,
+                                              Excess_Gas_Entropy_Ref_Liquid)
 
-ExcessEntropyRefSolid = PhaseTPPropertyBuilder('S_excess',
-                                               Excess_Solid_Entropy_Ref_Solid,
-                                               Excess_Liquid_Entropy_Ref_Solid,
-                                               Excess_Gas_Entropy_Ref_Solid)
+ExcessEntropyRefSolid = PhaseTPFunctorBuilder('S_excess',
+                                             Excess_Solid_Entropy_Ref_Solid,
+                                             Excess_Liquid_Entropy_Ref_Solid,
+                                             Excess_Gas_Entropy_Ref_Solid)
 
-ExcessEntropyRefGas = PhaseTPPropertyBuilder('S_excess',
-                                             Excess_Solid_Entropy_Ref_Gas,
-                                             Excess_Liquid_Entropy_Ref_Gas,
-                                             Excess_Gas_Entropy_Ref_Gas)
\ No newline at end of file
+ExcessEntropyRefGas = PhaseTPFunctorBuilder('S_excess',
+                                           Excess_Solid_Entropy_Ref_Gas,
+                                           Excess_Liquid_Entropy_Ref_Gas,
+                                           Excess_Gas_Entropy_Ref_Gas)
\ No newline at end of file
